@@ -59,45 +59,37 @@ class Card(object):
         self.bitmap = None
         self._suit = SUITS[self._suit_name]
         self._value = RANKS.index(self._rank)
+        self._order = (13 * SUIT_NAMES.index(self._suit_name)) + self._value
         self._is_honour = self._value >= 10
         self._high_card_points = max(0, self._value-9)
         self.play_note_index = None
 
     def __eq__(self, other):
-        if self._name == other.name:
-            return True
-        return False
+        return self._name == other.name
 
     def __ne__(self, other):
-        return not self.__eq__(other)
+        return self._name != other.name
 
     def __gt__(self, other):
         if self._suit == other.suit:
-            if self._value > other.value:
-                return True
-        else:
-            return False
+            return self._value > other.value
+        return self._suit > other.suit
 
     def __ge__(self, other):
         if self._suit == other.suit:
-            if self._value >= other.value:
-                return True
-        else:
-            return False
+            return self._value >= other.value
+        return self._suit >= other.suit
 
     def __lt__(self, other):
         if self._suit == other.suit:
-            if self._value < other.value:
-                return True
-        else:
-            return False
+            return self._value < other.value                
+        return self._suit < other.suit
+            
 
     def __le__(self, other):
         if self._suit == other.suit:
-            if self._value <= other.value:
-                return True
-        else:
-            return False
+            return self._value <= other.value
+        return self._suit <= other.suit
 
     def __repr__(self):
         return f'Card("{self._name}")'
@@ -121,6 +113,13 @@ class Card(object):
         """
         return self._rank
 
+    @property
+    def order(self):
+        """
+        The card's order expressed as (13 * suit rank) + value
+        """
+        return self._order
+
     @property
     def is_honour(self):
         """
@@ -128,6 +127,13 @@ class Card(object):
         """
         return self._is_honour
 
+    @is_honour.setter
+    def is_honour(self, value):
+        """
+        Set the value of is_honour.
+        """
+        self._is_honour = value
+
     @property
     def suit_name(self):
         """
