@@ -3,6 +3,7 @@
 from .denomination import Denomination
 from .call import Call
 from .suit import Suit
+from .auction import Auction
 from .constants import CONTRACTS, SEATS, SUITS
 
 __all__ = ['Contract']
@@ -26,12 +27,14 @@ class Contract(object):
     It is also identified (if appropriate) as either major, minor or no trumps.
     """
 
-    def __init__(self, name='', declarer=''):
+    def __init__(self, name='', declarer='', auction=None):
         self._name = name
+        self._declarer = declarer
+        self.auction = self._analyse_auction(auction)
         self._is_nt = False
-        if name and self._is_valid(name):
-            self._call = Call(name)
-            self._denomination = self._get_denomination(name)
+        if self._name and self._is_valid(self._name):
+            self._call = Call(self._name)
+            self._denomination = self._get_denomination(self._name)
             if self._denomination:
                 self._is_nt = self._denomination.is_nt
             if self._is_nt:
@@ -42,7 +45,10 @@ class Contract(object):
             self._trump_suit = None
             self._call = Call('')
             self._denomination = None
-        self._declarer = declarer
+        if self._name:
+            self._level = int(self._name[0])
+        else:
+            self._level = 0
 
     def __repr__(self):
         """Return the repr string for the object."""
@@ -64,6 +70,13 @@ class Contract(object):
             raise ValueError(f"'{value}' is not a valid seat")
         self._declarer = value
 
+    @property
+    def leader(self):
+        """Return the dealer value."""
+        if self._declarer:
+           return SEATS[(SEATS.index(self._declarer) + 1) % 4]
+        return None
+
     @property
     def name(self):
         """Return the name value."""
@@ -114,6 +127,11 @@ class Contract(object):
         self._denomination = Denomination(value.name)
         self._trump_suit = value
 
+    @property
+    def level(self):
+        """Return the level value."""
+        return self._level
+
     @property
     def denomination(self):
         """Return the denomination value."""
@@ -138,3 +156,46 @@ class Contract(object):
             return Denomination('NT')
         else:
             return Denomination(name[1])
+
+    def _analyse_auction(self, auction):
+        """Generate name and declarer from auction and return auction."""
+        if auction:
+            if auction.calls and auction.first_caller:
+                if (self._three_final_passes(auction.calls) and
+                        not self._passed_out(auction.calls)):
+                    dealer_index = SEATS.index(auction.first_caller)
+
+                    auction_calls = [call for call in auction.calls]
+                    auction_calls.reverse()
+                    for call in auction_calls:
+                        if call.is_value_call:
+                            break
+
+                    denomination = call.denomination
+                    for index, check_call in enumerate(auction.calls):
+                        if check_call.denomination == denomination:
+                            break
+                    declarer_index = (dealer_index + index) % 4
+                    self._declarer = SEATS[declarer_index]
+                    self._name = call.name
+                    return auction
+        return None
+
+    @staticmethod
+    def _three_final_passes(calls):
+        """Return True if there have been three consecutive passes."""
+        three_passes = False
+        if len(calls) >= 4:
+            if calls[-1].is_pass and calls[-2].is_pass and calls[-3].is_pass:
+                three_passes = True
+        return three_passes
+
+    @staticmethod
+    def _passed_out(calls):
+        """Return True if the board has been passed out."""
+        if len(calls) != 4:
+            return False
+        for call in calls:
+            if not call.is_pass:
+                return False
+        return True
\ No newline at end of file
