@@ -166,6 +166,10 @@ def parse_pbn(file_lines):
                     event.boards.append(board)
                     trick_index = 0
 
+            # Board Description
+            elif tag == "Description":
+                board.description = value
+
             # Board West
             elif tag == "West":
                 board.west = value
@@ -245,7 +249,8 @@ def parse_pbn(file_lines):
             elif play_state:
                 trick = _parse_pbn_play_section(board, tag, value, line, first_player)
                 if trick:
-                    board.tricks[trick_index] = trick
+                    # board.tricks[trick_index] = trick
+                    board.tricks.append(trick)
                     trick_index += 1
     return events
 
@@ -314,7 +319,7 @@ def _parse_pbn_auction(board, tag, value, line):
             elif element[0] == '=':
                 board.auction.note_keys[call_index] = element.replace('=', '')
             else:
-                assert False, 'invalid element in calls: %s' % element
+                assert False, f'invalid element in calls: {element}'
 
 
 def _parse_pbn_play_section(board, tag, value, line, first_player):
@@ -560,7 +565,7 @@ def _parse_rbn_auction(value):
 
 
 def _get_rbn_contract(value):
-    """Return the contract vulnerability as a list of CALLS."""
+    """Return the contract."""
     contract = Contract(name=value)
     # if len(value) > 3:
     #     value = value[:3]
@@ -605,10 +610,11 @@ def _append_pbn_header():
 def _create_pbn_event(event):
     """Return an event as string in pbn format as a list."""
     output = []
-    output.append('[Event "%s"' % event.name)
-    output.append('[Site "%s"' % event.location)
+    output.append(f'[Event "{event.name}"]')
+    output.append(f'[Site "{event.location}"]')
     if event.date:
-        output.append('[Date "%s"' % event.date.strftime('%Y.%m.%d'))
+        event_date = event.date.strftime('%Y.%m.%d')
+        output.append(f'[Date "{event_date}"]')
     output.append('')
     for board in event.boards:
         output.extend(BoardAsString.create_pbn_board(event, board))
@@ -725,11 +731,12 @@ def _create_rbn_list(events):
 def _create_rbn_event(event):
     """Return an event as string in rbn format as a list."""
     output = []
-    output.append('E %s' % event.name)
-    output.append('L %s' % event.location)
+    output.append(f'E {event.name}')
+    output.append(f'L {event.location}')
     if event.date:
-        output.append('D %s' % event.date.strftime('%Y%m%d'))
-    output.append('M %s' % _question_from_null(event.scoring_method))
+        event_date = event.date.strftime('%Y%m%d')
+        output.append(f'D {event_date}')
+    output.append(f'M {_question_from_null(event.scoring_method)}')
     for board in event.boards:
         output.extend(_create_rbn_board(event, board))
     return output
@@ -737,12 +744,12 @@ def _create_rbn_event(event):
 
 def _create_rbn_board(event, board):
     """Return a board as a list of strings in pbn format."""
-    output = ['B %s' % board.identifier]
+    output = [f'B {board.identifier}']
 
     #  names
     names = _create_rbn_names(board)
     if names:
-        output.append('N %s' % names)
+        output.append(f'N {names}')
 
     # hands
     deal = _get_pbn_deal(board, ':')
@@ -757,12 +764,12 @@ def _create_rbn_board(event, board):
     board_declarer = _question_from_null(board.declarer)
     contract = ':'.join([board_contract.name, board_declarer])
     if contract != "?:?":
-        output.append('C %s' % contract)
+        output.append(f'C {contract}')
 
     # result
     result = _question_from_null(board.result)
     if result != "?":
-        output.append('[R %s' % result)
+        output.append(f'[R result')
     output.append('')
     return output
 
@@ -780,7 +787,7 @@ def _create_rbn_names(board):
 
 
 def _write_file(output, path, append):
-    """Write the list 'ouput' to a text file defined by path."""
+    """Write the list 'output' to a text file defined by path."""
     if not os.path.isfile(path):
         with open(path, "w") as pbn_file:
             pbn_file.write('')
@@ -793,7 +800,7 @@ def _write_file(output, path, append):
             pbn_file.write('\n'.join(output))
         success = True
     except FileNotFoundError:
-        logger.warning('invalid file path: %s. File not written', path)
+        logger.warning(f'invalid file path: {path}. File not written')
         success = False
     return success
 
@@ -868,34 +875,34 @@ class BoardAsString(object):
     @staticmethod
     def create_pbn_board(event, board):
         """Return a board as a list of strings in pbn format."""
-        output = ['[Board "%s"]' % board.identifier,
-                  '[West "%s"]' % board.west,
-                  '[North "%s"]' % board.north,
-                  '[East "%s"]' % board.east,
-                  '[South "%s"]' % board.south,
-                  '[Dealer "%s"]' % board.dealer]
+        output = [f'[Board "{board.identifier}"]',
+                  f'[West "{board.west}"]',
+                  f'[North "{board.north}"]',
+                  f'[East "{board.east}"]',
+                  f'[South "{board.south}"]',
+                  f'[Dealer "{board.dealer}"]']
         if board.description:
-            output.append('{Description "%s"}' % board.description)
+            output.append(f'[Description "{board.description}"]')
         if board.vulnerable:
-            output.append('[Vulnerable "%s"]' % board.vulnerable.replace('Both', 'All'))
-        output.append('[Deal "{}:{}"]'.format(board.dealer, _get_pbn_deal(board)))
+            vulnerability = board.vulnerable.replace("Both", "All")
+            output.append(f'[Vulnerable "{vulnerability}"]')
+        output.append(f'[Deal "{board.dealer}:{_get_pbn_deal(board)}"]')
         if event:
-            output.append('[Scoring "%s"]' % _question_from_null(event.scoring_method))
-        output.append('[Declarer "%s"]' % _question_from_null(board.contract.declarer))
+            output.append(f'[Scoring {_question_from_null(event.scoring_method)}]')
+        output.append(f'[Declarer {_question_from_null(board.contract.declarer)}]')
         if board.contract.call:
             question = _question_from_null(board.contract.call.name)
-            output.append('[Contract "%s"]' % question)
+            output.append(f'[Contract {question}]')
         if board.auction.calls:
             output.extend(_create_pbn_auction(board))
-        output.append('[Result "%s"]' % _question_from_null(board.result))
+        output.append(f'[Result {_question_from_null(board.result)}]')
         if board.tricks:
             output.extend(_create_pbn_play_section(board))
         output.append('')
         if board.play_notes:
             for key in board.play_notes:
-                note = '[Note "{}:{}"]'.format(key, board.play_notes[key])
+                note = f'[Note "{key}:{board.play_notes[key]}"]'
                 output.append(note)
             output.append('')
-        print(output)
         return output
 
